@@ -14,7 +14,7 @@ import pytest
 
 from packaging.markers import (
     Node, InvalidMarker, UndefinedComparison, UndefinedEnvironmentName, Marker,
-    _eval_op, default_environment, format_full_version,
+    default_environment, format_full_version,
 )
 
 
@@ -58,18 +58,22 @@ class TestNode:
     def test_repr(self, value):
         assert repr(Node(value)) == "<Node({0!r})>".format(str(value))
 
+    def test_base_class(self):
+        with pytest.raises(NotImplementedError):
+            Node("cover all the code").serialize()
+
 
 class TestOperatorEvaluation:
 
     def test_prefers_pep440(self):
-        assert _eval_op("2.7.10", ">", "2.7.9")
+        assert Marker('"2.7.9" < "foo"').evaluate(dict(foo='2.7.10'))
 
     def test_falls_back_to_python(self):
-        assert _eval_op("b", ">", "a")
+        assert Marker('"b" > "a"').evaluate(dict(a='a'))
 
     def test_fails_when_undefined(self):
         with pytest.raises(UndefinedComparison):
-            _eval_op("2.7.0", "~=", "invalid")
+            Marker("'2.7.0' ~= os_name").evaluate()
 
 
 FakeVersionInfo = collections.namedtuple(
@@ -129,7 +133,7 @@ class TestDefaultEnvironment:
             sys.implementation.version
         )
         if sys.implementation.version.releaselevel != "final":
-            iver = "{0}{1}[0]{2}".format(
+            iver = "{0}{1[0]}{2}".format(
                 iver,
                 sys.implementation.version.releaselevel,
                 sys.implementation.version.serial,
